ajdmom.mdl\_1fsv.mom
====================

.. automodule:: ajdmom.mdl_1fsv.mom

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      b_n
      dm
      dpoly
      m
      moment_comb
      moment_y
      poly2num
      sub_v
   
   

   
   
   

   
   
   



